@@ -23,20 +23,28 @@
 
 import vmpconfig as config
 import vmppybuild as pybuild
+##dor javascript installer
+#import vmpjbuild  as jbuild
 
 ##Module name
 name="base"
 
 pysetup=pybuild.pysetup()
-pysetup.dirmain="{0}{1}/".format(config.gmodules_,name)
 pysetup.dependencies=['vmp','vmp_plugin']
 
+#jsetup=jbuild.jsetup()
+#jsetup.dirmain=config.gmodule_jsmain(name)
+#jsetup.index=[("index","title page","roottag",["file"],["file"])...(name,title page,root tag,[css file list] [javascript file list]]
+#jsetup.dependencies=["vmp"]
+
 def description():
     return "description module"
     
 def install():
     pybuild.pybuild(pysetup)
+    #jbuild.jbuild(jsetup)
 
 def uninstall():
     pybuild.pyclear(pysetup)
+    #jbuild.jclear(jsetup) 
 
