@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 09/04/2024
+#Date last Update : 06/11/2024
 
 import vmpsys as sys
 
@@ -33,7 +33,7 @@ webpage_="http://www.ragnu.it"
 license_="GPL3"
 
 ##Vampiria version
-version_="0.6.2"
+version_="0.7.1"
 
 ##Vampiria release type
 release_="alpha"
@@ -73,6 +73,9 @@ fwpylibso_="{0}pylib/".format(frmwk_)
 ##Framework main path
 fwmain_="{0}main/".format(frmwk_)
 
+##Framework web path(javascript library)
+fwweb_="{0}web/".format(frmwk_)
+
 ##Framework python main executable
 fwmainexe_="vmpmain.py"
 
@@ -155,6 +158,19 @@ def gmodulemanifest_path_(modname):
   main=gmodule_main_(modname)
   return "{0}{1}".format(main,gmodulemanifest_)
 
+##Subdirectory to locate main in module(default value)
+gmodulejs_="web/"
+
+##javascript package directory
+wpkg_="wpkg/"
+
+##Returns module javascript main directory path absolute path<BR>
+#
+#@param modname module name
+#@param subdir subdirectory javascript in in module
+def gmodule_jsmain(modname,subdir=gmodulejs_):
+  return "{0}{1}".format(sys.path(gmodule_path_(modname)),subdir)
+
 ##dtd module file
 gmoduledtd_="module.dtd"
 
@@ -230,6 +246,15 @@ pyclean_check_=['py3clean','--version']
 ##Python clean cmd
 pyclean_cmd_="py3clean -v {0}".format(root_)
 
+##Directory in the javascript program where libraries are copied
+jlib_="lib/"
+
+##Directory main javascript program
+jmain_="main/"
+
+##Favicon web image
+jfavicon_="favicon.ico"
+
 ##Cpp section
 
 ##Compiler help command
@@ -309,10 +334,33 @@ configlist_= ["/*Config file autogenerate from install*/",
               "#define VPYMAIN             \"{0}{1}{2}\"".format(root_,fwmain_,fwmainexe_),
               "#define VPYMAINAME          \"{0}\"".format(gpymain_),
               "#define VXMLHDR             \"{0}\"".format(gmodulexmlhdr_),  
+              "#define VWEB                \"{0}\"".format(fwweb_),
+              "#define VMODULEJS           \"{0}\"".format(gmodulejs_),
               "",
               "}",
               "",
               "#endif",
               ""
              ]
-
+##Returns the root path of a javascript library<BR>
+#
+#@param libname library name<BR>
+#@param pkg is it an external package to the framework?<BR>
+#@return root path
+def frm_jsrootlib(libname,pkg):
+  if not pkg:
+    return sys.path("{0}{1}/".format(fwweb_,libname))
+  else:
+    return sys.path("{0}{1}/".format(wpkg_,libname))
+  
+##config.h framework define
+configjs_= ["/*Config file autogenerate from install*/",
+              "",
+              "const VAUTHOR=\"{0}\"".format(author_),
+              "const VEMAIL=\"{0}\"".format(email_),
+              "const VWEBPAGE=\"{0}\"".format(webpage_),
+              "const VLICENSE=\"{0}\"".format(license_),
+              "const VVERSION=\"{0}_{1}\"\n".format(version_,release_),
+              ""
+           ]
+             
