@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 20/02/2024
+#Date last Update : 06/11/2024
 
 import vmpsys    as sys
 import vmpconfig as config
@@ -123,8 +123,8 @@ def clear():
 
 vmplib=clib()
 vmplib.name='vmp'
-vmplib.hdr=['assert.h','dirent.h','errno.h','fcntl.h','ctype.h','pthread.h','pty.h','signal.h','sys/time.h','sys/stat.h','sys/types.h','sys/wait.h','sys/ioctl.h','net/if.h','string.h','strings.h','stdarg.h','stdio.h','stdlib.h','time.h','unistd.h']
-vmplib.files=[('./',['args','basetypes','buf','env','error','io','lib','math','signal','thread','time','unicode','utils'])]
+vmplib.hdr=['assert.h','dirent.h','errno.h','fcntl.h','ctype.h','pthread.h','pty.h','signal.h','sys/time.h','sys/stat.h','sys/types.h','sys/wait.h','sys/ioctl.h','sys/sysmacros.h','net/if.h','string.h','strings.h','stdarg.h','stdio.h','stdlib.h','time.h','unistd.h']
+vmplib.files=[('./',['args','basetypes','buf','env','error','io','math','signal','thread','time','unicode','utils']),('lib/',['dev','fd','fs','lib','proc','types'])]
 vmplib.loptions=['-pthread','-lutil','-lc']
 vmplib.config=True
 clibs_[vmplib.name]=vmplib
@@ -153,13 +153,13 @@ clibs_[eventlib.name]=eventlib
 netlib=clib()
 netlib.name='net'
 netlib.hdr=['sys/socket.h','netdb.h']
-netlib.files=[('./',['address','dns','net','netdevice','socket','tcp','udp']),('connection/',['cb','connection','udpcb','tcpcb'])]
+netlib.files=[('./',['address','dns','net','netdevice','socket','tcp','udp','socks']),('connection/',['cb','connection','udpcb','tcpcb','proxy','proxycb','eventsocks','sockscb'])]
 netlib.dependencies=['vmp','event']
 clibs_[netlib.name]=netlib
 
 packetlib=clib()
 packetlib.name='packet'
-packetlib.files=[('./',['arp','ethernet','ip','packet','raw','tl']),('datatypes/',['address','bitwise','buffer','datatypes','size','types'])]
+packetlib.files=[('./',['arp','ethernet','ip','packet','raw','tl']),('datatypes/',['address','bitwise','buffer','datatypes','number','size','str','types']),('http/',['http','protocol']),('websocket/',['ext','helper','websocket'])]
 packetlib.dependencies=['vmp','net']
 clibs_[packetlib.name]=packetlib
 
@@ -180,10 +180,41 @@ clibs_[moduleslib.name]=moduleslib
 
 jsonlib=clib()
 jsonlib.name='json'
-jsonlib.files=[('./',['json','japi','jdata','jtable','jlist','jrp','status'])]
+jsonlib.files=[('./',['json','japi','jdata','jtable','jlist'])]
 jsonlib.dependencies=['vmp','event','net','packet']
 jsonlib.libs=[('json-c','0.16')]
 jsonlib.loptions=['`pkg-config json-c --cflags --libs`']
 clibs_[jsonlib.name]=jsonlib
 
+rawnetlib=clib()
+rawnetlib.name='rawnet'
+rawnetlib.dependencies=['vmp','packet','event']
+rawnetlib.files=[('./',['arpui','lib','rawnet','rawevent','rawui'])]
+rawnetlib.libs=[('libpcap','1.10.3')]
+rawnetlib.coptions=['`pkg-config --cflags libpcap`']
+rawnetlib.loptions=['`pkg-config --libs  libpcap`']
+clibs_[rawnetlib.name]=rawnetlib
+
+dblib=clib()
+dblib.name='db'
+dblib.dependencies=['vmp']
+dblib.files=[('./',['db'])]
+dblib.libs=[('sqlite3','3.40.1')]
+dblib.loptions=['`pkg-config sqlite3 --cflags --libs`']
+clibs_[dblib.name]=dblib
+
+cryptolib=clib()
+cryptolib.name='crypto'
+cryptolib.dependencies=['vmp','net','event','json','packet','db']
+cryptolib.cmd=['openssl version','chmod --version','cp --version']
+cryptolib.files=[('./',['crypto','eventssl','eventp2p','eventwss','lib','hash','pkey','ssl','x509']),('ctx/',['ctx','base','https','peer']),('cb/',['sslcb','framingcb','p2pcb','wsscb'])]
+cryptolib.libs=[('openssl','3.0.9')]
+cryptolib.loptions=['`pkg-config --libs  openssl`']
+clibs_[cryptolib.name]=cryptolib
+
+jrplib=clib()
+jrplib.name='jrp'
+jrplib.dependencies=['vmp','net','event','json','crypto']
+jrplib.files=[('./',['eventjrp','jrp','jrpreq','lib',]),('cb/',['cb','jrpui','wssui']),('misc/',['status'])]
+clibs_[jrplib.name]=jrplib
 
