@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 15/03/2024
+#Date last Update : 05/11/2024
 
 import vmpsys    as sys
 import vmpconfig as config
@@ -105,7 +105,7 @@ def clear():
 vmp=pylib()
 vmp.name='vmp'
 vmp.cbuild()
-vmp.setup.files=[('./',['buf_','env_','fs_','thread_','time_','unicode_','utils_','vmp_'])]
+vmp.setup.files=[('./',['buf_','env_','fs_','pairlist_','thread_','time_','unicode_','utils_','vmp_'])]
 vmp.setup.dependencies=['vmp','pylib']
 pylibs_[vmp.name]=vmp
 
@@ -120,7 +120,7 @@ pylibs_[event.name]=event
 net=pylib()
 net.name='vmp_net'
 net.cbuild()
-net.setup.files=[('./',['address_','macaddress_','net_','netdevice_','tcp_','udp_'])]
+net.setup.files=[('./',['address_','macaddress_','net_','netdevice_','tcp_','udp_','socks_'])]
 net.setup.dependencies=['vmp','pylib','net']
 pylibs_[net.name]=net
 
@@ -134,7 +134,7 @@ pylibs_[xml.name]=xml
 packet=pylib()
 packet.name='vmp_packet'
 packet.cbuild()
-packet.setup.files=[('./',['packet_'])]
+packet.setup.files=[('./',['packet_','http_','websocket_'])]
 packet.setup.dependencies=['vmp','pylib','packet']
 pylibs_[packet.name]=packet
 
@@ -146,8 +146,39 @@ pylibs_[plugin.name]=plugin
 json=pylib()
 json.name='vmp_json'
 json.cbuild()
-json.setup.files=[('./',['json_','jdata_','jlist_','jtable_','japi_','jrp_','status_'])]
+json.setup.files=[('./',['json_','jdata_','jlist_','jtable_','japi_'])]
 json.setup.dependencies=['vmp','pylib','json','net','packet']
 pylibs_[json.name]=json
 
+rawnet=pylib()
+rawnet.name='vmp_rawnet'
+rawnet.dependencies=['vmp','vmp_event','vmp_packet']
+rawnet.cbuild()
+rawnet.setup.files=[('./',['arpui_','rawnet_','rawui_'])]
+rawnet.setup.dependencies=['pylib','rawnet']
+pylibs_[rawnet.name]=rawnet
+
+db=pylib()
+db.name='vmp_db'
+db.dependencies=['vmp']
+db.cbuild()
+db.setup.files=[('./',['db_'])]
+db.setup.dependencies=['pylib','db']
+pylibs_[db.name]=db
+
+vmp_crypto=pylib()
+vmp_crypto.name='vmp_crypto'
+vmp_crypto.dependencies=['vmp','vmp_net','vmp_event']
+vmp_crypto.cbuild()
+vmp_crypto.setup.files=[('./',['crypto_','hash_','pkey_','ctx_','ssl_','x509_'])]
+vmp_crypto.setup.dependencies=['pylib','crypto']
+pylibs_[vmp_crypto.name]=vmp_crypto
+
+vmp_jrp=pylib()
+vmp_jrp.name='vmp_jrp'
+vmp_jrp.dependencies=['vmp','vmp_net','vmp_event','vmp_crypto','vmp_json','vmp_plugin']
+vmp_jrp.cbuild()
+vmp_jrp.setup.files=[('./',['eventjrp_','jrp_','jrpreq_','status_'])]
+vmp_jrp.setup.dependencies=['pylib','jrp']
+pylibs_[vmp_jrp.name]=vmp_jrp
 
