@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 26/03/2024
+   Date last update: 30/05/2024
  */
 
 #include "vmp_.h"
@@ -75,6 +75,8 @@ void vmp_init_unicode(pylib::Module module)
     unicode.def_("str_istype",vmp::unicode::str_istype);
     unicode.def_("str_todigit",vmp::unicode::str_todigit);
     unicode.def_("str_todigit_range",vmp::unicode::str_todigit_range);
+    unicode.def_("str_todigit64",vmp::unicode::str_todigit64);
+    unicode.def_("str_todigit64_range",vmp::unicode::str_todigit64_range);
     unicode.def_("str_toreal",vmp::unicode::str_toreal);
     unicode.def_("str_toreal_range",vmp::unicode::str_toreal_range);
     unicode.def_("xstr_tobytes",vmp::unicode::xstr_tobytes);
