@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 01/02/2024
+   Date last update: 30/09/2024
  */
 
 #include "vmp_.h"
@@ -140,7 +140,11 @@ void vmp_init(pylib::Module module)
     module.add_const<vmp_uchar>("UCHARMIN",vmp::UCHARMIN);
     module.add_const<vmp_uchar>("UCHARMAX",vmp::UCHARMAX);
     module.add_const<vmp_uint>("RANDMAX",vmp::RANDMAX);
-
+    module.add_const<vmp_int64>("INT64MIN",vmp::INT64MIN);
+    module.add_const<vmp_int64>("INT64MAX",vmp::INT64MAX);
+    module.add_const<vmp_uint64>("UINT64MIN",vmp::UINT64MIN);
+    module.add_const<vmp_uint64>("UINT64MAX",vmp::UINT64MAX);
+    
     //vmp/error.h
     module.def_with_stub("except_s",stub_except_s());
     module.def_("get_errno",vmp::get_errno);
@@ -169,20 +173,30 @@ void vmp_init(pylib::Module module)
     module.def_("copy_file",vmp::copy_file);
     module.def_("move_file",vmp::move_file);
 
-    //vmp/lib.h
+    //vmp/lib/process.h
     module.def_("system_wrap",vmp::system_wrap);
     module.def_("pause_wrap",vmp::pause_wrap);
     module.def_("getpid_wrap",vmp::getpid_wrap);
     module.def_("getuid_wrap",vmp::getuid_wrap);
     module.def_("geteuid_wrap",vmp::geteuid_wrap);
-    module.def_("dup2_wrap",vmp::dup2_wrap);
     module.def_("kill_wrap",vmp::kill_wrap);
+    
+    //vmp/lib/fd.h
+    module.def_("dup2_wrap",vmp::dup2_wrap);
     module.def_("fd_noblock",vmp::fd_noblock);
     module.def_("fd_block",vmp::fd_block);
     module.def_("fd_fsync",vmp::fd_fsync);
+    
+    //vmp/lib/types.h
     module.def_("srand_wrap",vmp::srand_wrap);
     module.def_with_stub("rand_wrap",stub_rand_wrap());
-   
+    
+    //vmp/lib/dev.h
+    pylib::Class<vmp::Dev_t_wrap> dev=module.class_<vmp::Dev_t_wrap>("Dev_t_wrap");
+    dev.def_("set_values",&vmp::Dev_t_wrap::set_values);
+    dev.def_("get_major",&vmp::Dev_t_wrap::get_major);
+    dev.def_("get_minor",&vmp::Dev_t_wrap::get_minor);
+    
     //vmp/signal.h
     module.def_("signum",vmp::signum);
     module.def_("sigstr",vmp::sigstr);
@@ -200,5 +214,6 @@ void vampiria_pylib_init_module(pylib::Module init_module)
    vmp_init_time(init_module);
    vmp_init_unicode(init_module);
    vmp_init_utils(init_module);
+   vmp_init_pairlist(init_module);
 }
 
