@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 27/03/2024
+ * Date last update: 06/11/2024
  */
 
 #include "pylib.h"
@@ -91,54 +91,9 @@ void json_jtable(pylib::Module module);
 /*!
     Function c++ in json/japi.h:<BR>japi(),japi_type_list(),japi_type_table(),japi_void(),japi_list(),japi_table(),
                                     japi_oper(),japi_oper_kill(),japi_oper_data(),japi_oper_push(),japi_oper_close(),japi_status(),
-                                    japi_status_update(),japi_status_cancel()
+                                    japi_status_update(),japi_status_cancel(),japi_login(),japi_login_b64_e(),japi_login_b64_d()
 */
 void json_japi(pylib::Module module);
 
-//!Python wrapper of the c++ namespace vampiria::json in vmp_json.(see c++ doc)
-/*!
-    Function c++ in json/status.h:<BR>status_input(),status_response()
-*/
-/*!
-    Status class in json/status.h:<BR>Constructor Status(dirpath,cached=true)<BR>
-    Status member function list:<BR>root(),backup(),keys(),update(),update_from_japi(),cancel(),cancel_from_japi(),search(),
-                                    request_open(),request_close()
-*/
-void json_status(pylib::Module module);
-
-//! Python wrapper of the c++ namespace vampiria::json::jrp in vmp_json.jrp(see c++ doc)
-/*!
-    Const c++ jrp status in json/jrp.h:<BR>status_ok,status_err,status_malformed_msg,status_undef_datatype,status_accessdenied,
-                                        status_duplexsession,status_protocolbad,status_closeconnection,status_timeout,status_killed,
-                                        status_input_bad,status_input_bad,status_input_notmanaged,status_rid_duplex,status_resource_busy,
-                                        status_resource_accessdenied<BR>
-*/
-/*!
-    Const c++ jrp permits limits in json/jrp.h<BR>min_permits,max_permits
-*/
-/*!
-    function c++ in json/jrp.h:<BR>msg_status()
-*/
-/*!
-    JrpReqData class in json/jrp.h:<BR>no Constructor<BR>
-    JrpReqData member function list:<BR>input(),push(),response(),permits_s(),permits()
-*/
-/*!
-    JrpReqSession class in json/jrp.h:<BR>Constructor JrpReqSession()<BR>
-    JrpReqSession member function list:<BR>reset(),permits(),match_reqdata(),
-                                           add_reqdata(),search_reqdata,all_input(),search_push(),search_response()
-                                           
-*/
-/*!
-    JrpReq class in json/jrp.h:<BR>no Constructor<BR>
-    JrpReq member function list:<BR>type(),cell(),rid(),jdata_type(),key(),
-                                    jdata_json(),jdata_root(),status(),msg(),
-                                    alloc_internal(),alloc(),release_internal(),
-                                    release(),push(),response(),kill(),close(),
-                                    request_oper(),kill_oper(),send_from_oper()
-                                           
-*/
-void json_jrp(pylib::Module module);
-
 #endif
 
