@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 28/02/2024
+#Date last Update : 25/10/2024
 
 ##@package vmp_net
 #
@@ -38,19 +38,50 @@ from vmp_net_ import is_macaddress_raw     as is_macaddress_raw
 from vmp_net_ import macaddress_to_buf     as macaddress_to_buf
 from vmp_net_ import macaddress_from_buf   as macaddress_from_buf
 
-from vmp_net_ import CONN_NONE        as CONN_NONE
-from vmp_net_ import CONN_UDP4        as CONN_UDP4
-from vmp_net_ import CONN_UDP6        as CONN_UDP6
-from vmp_net_ import CONN_UDPCONNECT  as CONN_UDPCONNECT
-from vmp_net_ import CONN_UDPPROXY    as CONN_UDPPROXY
-from vmp_net_ import CONN_TCPLISTEN   as CONN_TCPLISTEN
-from vmp_net_ import CONN_TCPSERVER   as CONN_TCPSERVER
-from vmp_net_ import CONN_TCPCLIENT   as CONN_TCPCLIENT
-from vmp_net_ import CONN_TCPPROXY    as CONN_TCPPROXY
+from vmp_net_ import CONN_NONE         as CONN_NONE
+from vmp_net_ import CONN_UDP4         as CONN_UDP4
+from vmp_net_ import CONN_UDP6         as CONN_UDP6
+from vmp_net_ import CONN_UDPCONNECT   as CONN_UDPCONNECT
+from vmp_net_ import CONN_UDPPROXY     as CONN_UDPPROXY
+from vmp_net_ import CONN_TCPLISTEN    as CONN_TCPLISTEN
+from vmp_net_ import CONN_TCPSERVER    as CONN_TCPSERVER
+from vmp_net_ import CONN_TCPCLIENT    as CONN_TCPCLIENT
+from vmp_net_ import CONN_TCPPROXY     as CONN_TCPPROXY
+from vmp_net_ import CONN_TCPBIND      as CONN_TCPBIND
+from vmp_net_ import CONN_TCPBINDPROXY as CONN_TCPBINDPROXY
 
 from vmp_net_ import conn_strtype     as conn_strtype
 
-from vmp_net_ import ProxyInfo        as ProxyInfo
+from vmp_net_ import socks_cd_connect      as socks_cd_connect
+from vmp_net_ import socks_cd_bind         as socks_cd_bind
+from vmp_net_ import socks_cd_udpassociate as socks_cd_udpassociate
+
+from vmp_net_ import socks4_result_granted         as socks4_result_granted
+from vmp_net_ import socks4_result_failed          as socks4_result_failed
+from vmp_net_ import socks4_result_reject          as socks4_result_reject
+from vmp_net_ import socks4_result_rejectuserid    as socks4_result_rejectuserid
+from vmp_net_ import socks5_result_ok              as socks5_result_ok
+from vmp_net_ import socks5_result_failure         as socks5_result_failure
+from vmp_net_ import socks5_result_notallowed      as socks5_result_notallowed
+from vmp_net_ import socks5_result_netunreachable  as socks5_result_netunreachable
+from vmp_net_ import socks5_result_hostunreachable as socks5_result_hostunreachable
+from vmp_net_ import socks5_result_refused         as socks5_result_refused
+from vmp_net_ import socks5_result_ttlexpired      as socks5_result_ttlexpired 
+from vmp_net_ import socks5_result_badcmd          as socks5_result_badcmd 
+from vmp_net_ import socks5_result_badatype        as socks5_result_badatype 
+from vmp_net_ import socks_internal_badauth        as socks_internal_badauth
+from vmp_net_ import socks_internal_badaddr        as socks_internal_badaddr 
+from vmp_net_ import socks_internal_accessdenied   as socks_internal_accessdenied 
+from vmp_net_ import socks_msg_result              as socks_msg_result 
+
+from vmp_net_ import evtsocks_status_init        as evtsocks_status_init
+from vmp_net_ import evtsocks_status_request     as evtsocks_status_request
+from vmp_net_ import evtsocks_status_bind        as evtsocks_status_bind
+from vmp_net_ import evtsocks_status_established as evtsocks_status_established
+from vmp_net_ import evtsocks_status_close       as evtsocks_status_close
+
+from vmp_net_ import Proxy                         as Proxy
+from vmp_net_ import ProxyChain                    as ProxyChain
 
 from vmp_net_ import UDP_MSIZE_DEFAULT     as UDP_MSIZE_DEFAULT
 from vmp_net_ import socket_datagram       as socket_datagram
@@ -79,5 +110,6 @@ from vmp_net_ import udpui               as udpui
 from vmp_net_ import UdpUI               as UdpUI
 from vmp_net_ import tcpui               as tcpui
 from vmp_net_ import TcpUI               as TcpUI
- 
+from vmp_net_ import socksui             as socksui
+from vmp_net_ import SocksUI             as SocksUI
 
