@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 01/03/2024
+   Date last update: 28/10/2024
  */
 
 #include "net_.h"
@@ -35,6 +35,11 @@ class PyTcpUI:public net::TcpUI
         pylib::PyCall pysvlcevent_;
         pylib::PyCall pysvrevent_;
         pylib::PyCall pysvcevent_;
+        
+        pylib::PyCall pybind_;
+        pylib::PyCall pybindconnect_;
+        pylib::PyCall pybindrecv_;
+        pylib::PyCall pybindclose_;
 };
 
 PyTcpUI::PyTcpUI(event::Manager *manager):net::TcpUI(manager)
@@ -203,6 +208,78 @@ struct stub_TcpUI_set_event_server:public pylib::Member_def<PyTcpUI>
     }
 };
 
+void tcp_pybind(event::Cell *cell)
+{
+    PyTcpUI *tcpui=cell->ui<PyTcpUI>();
+    pylib::CArgs cargs(1);
+    cargs.add<event::Cell *>(cell,false);
+    tcpui->pybind_.call(cargs);
+}
+
+void tcp_pybindconnect(event::Cell *cell)
+{
+    PyTcpUI *tcpui=cell->ui<PyTcpUI>();
+    pylib::CArgs cargs(1);
+    cargs.add<event::Cell *>(cell,false);
+    tcpui->pybindconnect_.call(cargs);
+}
+
+void tcp_pybindrecv(event::Cell *cell,vmp::Buf *buf)
+{
+    PyTcpUI *tcpui=cell->ui<PyTcpUI>();
+    pylib::CArgs cargs(2);
+    cargs.add<event::Cell *>(cell,false);
+    cargs.add<vmp::Buf *>(buf,false);
+    tcpui->pybindrecv_.call(cargs);
+}
+
+void tcp_pybindclose(event::Cell *cell)
+{
+    PyTcpUI *tcpui=cell->ui<PyTcpUI>();
+    pylib::CArgs cargs(1);
+    cargs.add<event::Cell *>(cell,false);
+    tcpui->pybindclose_.call(cargs);
+}
+
+struct stub_TcpUI_set_event_bind:public pylib::Member_def<PyTcpUI>
+{
+    pylib::Objref *def(PyTcpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 4)
+        {
+            event::EVTCB bind;
+            event::EVTCB bindconnect;
+            event::EVTCBBUF bindrecv;
+            event::EVTCB bindclose;
+            
+            args.get_callable(0,instance->pybind_);
+            args.get_callable(1,instance->pybindconnect_);
+            args.get_callable(2,instance->pybindrecv_);
+            args.get_callable(3,instance->pybindclose_);
+            
+            if(pylib::is_none(instance->pybind_.ref()))
+                bind=0;
+            else 
+                bind=tcp_pybind;
+            if(pylib::is_none(instance->pybindconnect_.ref()))
+                bindconnect=0;
+            else 
+                bindconnect=tcp_pybindconnect;
+            if(pylib::is_none(instance->pybindrecv_.ref()))
+                bindrecv=0;
+            else 
+                bindrecv=tcp_pybindrecv;
+            if(pylib::is_none(instance->pybindclose_.ref()))
+                bindclose=0;
+            else 
+                bindclose=tcp_pybindclose;
+            instance->set_event_bind(bind,bindconnect,bindrecv,bindclose);
+            return pylib::retnone();                      
+        }
+        return 0;
+    }
+};
+
 struct stub_TcpUI_new_client:public pylib::Member_def<PyTcpUI>
 {
     pylib::Objref *def(PyTcpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
@@ -215,15 +292,39 @@ struct stub_TcpUI_new_client:public pylib::Member_def<PyTcpUI>
         else if(args.size() == 2)
         {
             net::Address *peer=args.get<net::Address *>(0);
-            net::ProxyInfo *proxy=0;
+            net::ProxyChain *proxy=0;
             if(!args.is_none(1))
-                proxy=args.get<net::ProxyInfo *>(1);
+                proxy=args.get<net::ProxyChain *>(1);
             return pylib::Converter<event::Cell *>(instance->new_client(peer,proxy),false);
         }
         return 0;
     }
 };
-    
+
+struct stub_TcpUI_new_bind:public pylib::Member_def<PyTcpUI>
+{
+    pylib::Objref *def(PyTcpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 3)
+        {
+            net::Address *bindref=args.get<net::Address *>(0);
+            net::Address *bindservice=args.get<net::Address *>(1);
+            vmp::time::Time bindwait=args.get<vmp::time::Time>(2);
+            return pylib::Converter<event::Cell *>(instance->new_bind(bindref,bindservice,bindwait),false);
+        }
+        else if(args.size() == 4)
+        {
+            net::Address *bindref=args.get<net::Address *>(0);
+            net::Address *bindservice=args.get<net::Address *>(1);
+            vmp::time::Time bindwait=args.get<vmp::time::Time>(2);
+            net::ProxyChain *proxy=0;
+            if(!args.is_none(3))
+                proxy=args.get<net::ProxyChain *>(3);
+            return pylib::Converter<event::Cell *>(instance->new_bind(bindref,bindservice,bindwait,proxy),false);
+        }
+        return 0;
+    }
+}; 
 void net_init_tcpui(pylib::Module module)
 {
     //Wrapper cell->ui()
@@ -233,12 +334,16 @@ void net_init_tcpui(pylib::Module module)
     pylib::Class<PyTcpUI> tcpui=module.class_with_constructor<PyTcpUI>("TcpUI",TcpUI_Constructor());
     tcpui.def_with_stub("set_event_client",stub_TcpUI_set_event_client());
     tcpui.def_with_stub("set_event_server",stub_TcpUI_set_event_server());
-    tcpui.def_("new_server",&PyTcpUI::new_server,false);
+    tcpui.def_with_stub("set_event_bind",stub_TcpUI_set_event_bind());
     tcpui.def_with_stub("new_client",stub_TcpUI_new_client());
+    tcpui.def_("new_server",&PyTcpUI::new_server,false);
+    tcpui.def_with_stub("new_bind",stub_TcpUI_new_bind());
     tcpui.def_("send",&PyTcpUI::send);
     tcpui.def_("localaddr",&PyTcpUI::localaddr,false);
     tcpui.def_("peeraddr",&PyTcpUI::peeraddr,false);
-    tcpui.def_("proxyinfo",&PyTcpUI::proxyinfo,false);
+    tcpui.def_("bindaddr",&PyTcpUI::bindaddr,false);
+    tcpui.def_("bindservice",&PyTcpUI::bindservice,false);
+    tcpui.def_("proxychain",&PyTcpUI::proxychain,false);
     tcpui.def_("connection_type",&PyTcpUI::connection_type);
     tcpui.def_("connection_strtype",&PyTcpUI::connection_strtype);
 }
