@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 09/02/2024
+ * Date last update: 24/10/2024
  */
 
 #include "event.h"
@@ -26,6 +26,7 @@ namespace vampiria { namespace event {
 Cell::Cell()
 {
     reset();
+    id_=0;
 }
 
 Cell::~Cell()
@@ -58,10 +59,15 @@ void Cell::reset()
 
 vmp::str Cell::identity()
 {
-   manager_->lock();
-   vmp::str ret=ui_->identity(this); 
-   manager_->unlock();
-   return ret;
+    manager_->lock();
+    vmp::str ret=ui_->identity(this); 
+    manager_->unlock();
+    return ret;
+}
+
+vmp_index Cell::id()
+{
+    return id_;
 }
 
 void Cell::close(vmp::str closelevel)
@@ -106,6 +112,21 @@ void Cell::release()
     manager_->unlock();
 }
 
+void Cell::set_priority(vmp_uint priority)
+{
+   manager_->lock();
+   manager_->cell_set_priority(this,priority);
+   manager_->unlock();
+}
+
+vmp_uint Cell::get_priority()
+{
+   manager_->lock();
+   vmp_uint ret=manager_->cell_get_priority(this);
+   manager_->unlock();
+   return ret;
+}
+
 event::CELLRET Cell::ret()
 {
     manager_->lock();
@@ -148,12 +169,20 @@ void Cell::set_timewait(vmp::time::Time timewait)
 vmp::time::Time Cell::get_timewait()
 {
     manager_->lock();
-    vmp::time::Time ret=timewait_;
+    vmp::time::Time ret=manager_->cell_get_timewait(this);
     manager_->unlock();
     return ret;
      
 }
 
+vmp::time::Time Cell::get_timeout()
+{
+    manager_->lock();
+    vmp::time::Time ret=manager_->cell_get_timeout(this);
+    manager_->unlock();
+    return ret;
+}
+
 event::Manager *Cell::get_manager()
 {
     return manager_;
@@ -166,5 +195,46 @@ vmp_bool Cell::operator<(Cell &cell)
     return false;
 }
 
+event::Cell *Cell::master()
+{
+    event::Cell *ret;
+    manager_->lock();
+    ret=manager_->cell_master(this);
+    manager_->unlock();
+    return ret;
+}
+
+vmp::str Cell::subid()
+{
+    vmp::str ret;
+    manager_->lock();
+    ret=manager_->cell_subid(this);
+    manager_->unlock();
+    return ret;
+}
+
+void Cell::addsub(vmp::str sid,event::Cell *sub)
+{
+    manager_->lock();
+    manager_->cell_addsub(this,sid,sub);
+    manager_->unlock();
+}
+
+event::Cell *Cell::searchsub(vmp::str sid)
+{
+    event::Cell *cell;
+    manager_->lock();
+    cell=manager_->cell_searchsub(this,sid);
+    manager_->unlock();
+    return cell;
+}
+
+void Cell::delsub(vmp::str sid)
+{
+    manager_->lock();
+    manager_->cell_delsub(this,sid);
+    manager_->unlock();
+}
+
 }}
 
