@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 15/04/2019
+   Date last update: 10/06/2023
  */
 
 #include "event.h"
@@ -44,5 +44,10 @@ event::Event *UI::child_event_new(event::Cell *cell)
     return 0;
 }
 
+vmp::str UI::identity(event::Cell *cell)
+{
+    return "";
+}
+
 }}
 
