@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 10/08/2021
+ * Date last update: 14/01/2023
  */
 
 #include "event.h"
@@ -33,7 +33,7 @@ ThreadRef::~ThreadRef()
 
 ThreadUI::ThreadUI(event::Manager *manager):event::UI(manager)
 {
-    set_event(0,0,0);
+    set_event(0,0,0,0);
 }
         
 ThreadUI::~ThreadUI()
@@ -62,9 +62,10 @@ void ThreadUI::free_ref(event::Cell *cell)
     tref_.free(tevent);
 }
 
-void ThreadUI::set_event(event::EVTCB revent,event::EVTCB cancel,event::EVTCB cevent)
+void ThreadUI::set_event(event::EVTCB active,event::EVTCB run,event::EVTCB cancel,event::EVTCB cevent)
 {
-    revent_=revent;
+    active_=active;
+    run_=run;
     cancel_=cancel;
     cevent_=cevent;
 }
@@ -75,7 +76,7 @@ event::Cell *ThreadUI::new_thread(vmp::str id)
     ThreadRef *tevent=tref_.get();
     try
     {
-        cell=tevent->evt_thread_new(this,revent_,cancel_,cevent_);
+        cell=tevent->evt_thread_new(this,active_,run_,cancel_,cevent_);
         tevent->id_=id;
     }
     catch(vmp::exception &x)
@@ -88,6 +89,15 @@ event::Cell *ThreadUI::new_thread(vmp::str id)
     return cell;
 }
 
+void ThreadUI::active_main(event::Cell *cell)
+{
+    ThreadRef *tevent=cell->event<ThreadRef>();
+    event::Manager *manager=cell->get_manager();
+    manager->lock();
+    tevent->evt_thread_active();
+    manager->unlock();
+}
+
 void ThreadUI::start_thread(event::Cell *cell)
 {
     ThreadRef *tevent=cell->event<ThreadRef>();
