@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 20/02/2024
+   Date last update: 06/11/2024
  */
 
 #include "vmp.h"
@@ -163,6 +163,9 @@ class JsonObj
         //! A destructor
         ~JsonObj();
 
+        //! Reset data
+        void reset();
+        
         //! Check if an object is null
         vmp_bool isnull();
 
@@ -559,6 +562,4 @@ class JsonObj
 #include "json/jlist.h"
 #include "json/jtable.h"
 #include "json/japi.h"
-#include "json/jrp.h"
-#include "json/status.h"
 
