@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 01/03/2024
+ * Date last update: 29/10/2024
  */
 
 #include "net.h"
@@ -31,5 +31,19 @@ void empty_accept_ev(event::Cell *listen,event::Cell *server)
 {
 }
 
+vmp_uint empty_socksnoauth_ev(event::Cell *cell)
+{
+    return 0;
+}
+
+vmp_uint empty_socksuserpass_ev(event::Cell *cell,vmp::str user,vmp::str password)
+{
+    return 0;
+}
+
+void empty_socksrequest_ev(event::Cell *cell,net::Address *address)
+{
+}
+
 }}
 
