@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 01/03/2024
+ * Date last update: 28/10/2024
  */
 
 #ifndef VAMPIRIA_NET_TCP_H
@@ -41,6 +41,10 @@ class TcpUI:public event::UI
        event::EVTCBBUF  svrevent_;/*!< Recv data stream.Called when socket receive data server type*/
        event::EVTCB     svcevent_;/*! Close server callback*/
 
+       event::EVTCB bind_;/*!<Function performed when a bind event listened to*/
+       event::EVTCB bindconnect_;/*!<Function performed when a bind event that is listened to receives a connection*/
+       event::EVTCBBUF bindrecv_;/*!<Function performed when a bind event recv data stream*/
+       event::EVTCB bindclose_;/*!<Function performed when a bind event is close*/
     public:
        
        //!A Constructor
@@ -80,14 +84,23 @@ class TcpUI:public event::UI
            @param svcevent close connection server
        */
        void set_event_server(net::EVTCBACCEPT acptevent,event::EVTCB svlcevent,event::EVTCBBUF revent,event::EVTCB svcevent);
-
+       
+       //! Set bind event(see net::TcpUI::new_bind())
+       /*!
+           @param bind bind listened to
+           @param bindconnect bind recv connection
+           @param bindrecv receive data stream
+           @param bindclose close connection
+       */
+       void set_event_bind(event::EVTCB bind,event::EVTCB bindconnect,event::EVTCBBUF bindrecv,event::EVTCB bindclose);
+       
        //! Add tcp client event. Callback events assigned with set_event_client
        /*!
            @param peer remote server address
            @param proxy proxy information,if use proxy
            @return event cell or except in case of failure
        */
-       event::Cell *new_client(net::Address *peer,net::ProxyInfo *proxy=0);
+       event::Cell *new_client(net::Address *peer,net::ProxyChain *proxy=0);
 
        //! Add tcp server listen event. Callback events assigned with set_event_server
        /*!
@@ -96,7 +109,17 @@ class TcpUI:public event::UI
            @return event cell or except in case of failure
        */
        event::Cell *new_server(net::Address *local,vmp_size backlog);
-
+       
+       //! Listens for a tcp connection on a port for a maximum bindwait time and waits for a remote connection(see protocol ftp)
+       /*!
+           @param bindref address reference, a the ip of this address for the listen in a random port
+           @param bindrefservice remote address of the service associated with a bind connection
+           @param bindwait connection wait time
+           @param proxy proxy information,if use proxy
+           @return event cell or except in case of failure
+       */
+       event::Cell *new_bind(net::Address *bindref,net::Address *bindrefservice,vmp::time::Time bindwait,net::ProxyChain *proxy=0);
+       
        //! Send packet
        /*!
            @param cell event cell
@@ -119,12 +142,26 @@ class TcpUI:public event::UI
        */
        net::Address *peeraddr(event::Cell *cell);
        
+       //!Gets bind address,for bind connection
+       /*!
+           @param cell cell associated
+           @return bind address
+       */
+       net::Address *bindaddr(event::Cell *cell);
+       
+       //!Gets Remote address of the service associated with a bind connection
+       /*!
+           @param cell cell associated
+           @return remote service address
+       */
+       net::Address *bindservice(event::Cell *cell);
+       
        //! Gets peer proxy info(for client connection)
        /*!
           @param cell cell associated
-          @return proxy info or except in case of failure
+          @return proxy chain or except in case of failure
        */
-       net::ProxyInfo *proxyinfo(event::Cell *cell);
+       net::ProxyChain *proxychain(event::Cell *cell);
 
        //! Gets connection type(see EventConnection)
        /*!
