@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 25/01/2020
+   Date last update: 02/07/2023
  */
 
 #include "pylib.h"
@@ -114,7 +114,7 @@ static pylib::Objref *instance_new(pylib::Objtype *type,pylib::Objref *,pylib::O
     }
     pylib::instance<> *result = (pylib::instance<>*)type->tp_alloc(type,instance_size);
     if (result)
-        Py_SIZE(result) =-(static_cast<vmp_int>(offsetof(pylib::instance<>,storage_) + instance_size));
+        Py_SET_SIZE(result,-(static_cast<vmp_int>(offsetof(pylib::instance<>,storage_) + instance_size)));
     return (pylib::Objref*)result;
 }
 
@@ -224,7 +224,7 @@ void *instance_cpp::allocate(pylib::Objref *self_,vmp_size cpp_offset,vmp_size c
         vmp_assert(cpp_offset >= offsetof(pylib::instance<>,storage_));
 
         // Record the fact that the storage is occupied, noting where it starts
-        Py_SIZE(self) = cpp_offset;
+        Py_SET_SIZE(self,cpp_offset);
         return (vmp_byte *)self + cpp_offset;
     }
     else
@@ -256,7 +256,7 @@ pylib::Objref *class_metatype()
 {
       if (class_metatype_object.tp_dict == 0)
       {
-          Py_TYPE(&class_metatype_object) = &PyType_Type;
+          Py_SET_TYPE(&class_metatype_object,&PyType_Type);
           class_metatype_object.tp_base = &PyType_Type;
           if (PyType_Ready(&class_metatype_object))
               return 0;
@@ -269,7 +269,7 @@ pylib::Objref *class_type()
      if (class_type_object.tp_dict == 0)
      {
          pylib::incref(class_metatype());
-         Py_TYPE(&class_type_object) = (PyTypeObject *)class_metatype();
+         Py_SET_TYPE(&class_type_object,(PyTypeObject *)class_metatype());
          class_type_object.tp_base = &PyBaseObject_Type;
          if (PyType_Ready(&class_type_object))
              return 0;
