@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 13/01/2023
+   Date last update: 30/05/2024
  */
  
  #ifndef VAMPIRIA_PYLIB_PYBASE_H
@@ -47,13 +47,16 @@ void pyerr_clear();
 vmp::str pyunicode_asstring(pylib::Objref *obj);
 vmp_char pychar_aschar(pylib::Objref *obj);
 vmp_uchar pychar_asuchar(pylib::Objref *obj);
-vmp_int  pylong_aslong(pylib::Objref *obj);
-vmp_uint pylong_asulong(pylib::Objref *obj);
 vmp_int16 pylong_asint16(pylib::Objref *obj);
 vmp_uint16 pylong_asuint16(pylib::Objref *obj);
+vmp_int  pylong_aslong(pylib::Objref *obj);
+vmp_uint pylong_asulong(pylib::Objref *obj);
+vmp_int64 pylong_asint64(pylib::Objref *obj);
+vmp_uint64 pylong_asuint64(pylib::Objref *obj);
 vmp_bool pylong_asbool(pylib::Objref *obj);
 vmp_real pyfloat_asreal(pylib::Objref *obj);
 
+
 pylib::Objref *pyunicode_decode(vmp::str str);
 
 void pyerr_occurred();
