@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 26/03/2024
+   Date last update: 30/05/2024
  */
 
 #include "vmp.h"
@@ -168,6 +168,23 @@ vmp_int str_todigit_range(vmp::str istr,vmp_int min,vmp_int max)
     return ret; 
 }
 
+vmp_int64 str_todigit64(vmp::str istr)
+{
+    if(!vmp::unicode::str_istype(istr,"digit"))
+        vmp::except("Invalid Conversion from string to int64 because '%s' not integer",istr.c_str());   
+    return vmp::atoll_wrap(istr);    
+}
+
+vmp_int64 str_todigit64_range(vmp::str istr,vmp_int64 min,vmp_int64 max)
+{
+    if(min > max)
+        vmp::except("Min value %lld not less max value %lld in input",min,max);
+    vmp_int ret=vmp::unicode::str_todigit64(istr);
+    if((ret < min) || (ret > max))
+        vmp::except("%s not integer in range [%lld,%lld]",istr.c_str(),min,max);
+    return ret; 
+}
+
 vmp_real str_toreal(vmp::str dstr)
 {
     vmp_real ret;
