@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 27/03/2024
+   Date last update: 30/05/2024
  */
 
 #include <regex>
@@ -129,6 +129,23 @@ vmp_int str_todigit(vmp::str istr);
 */ 
 vmp_int str_todigit_range(vmp::str istr,vmp_int min,vmp_int max);
 
+//! Converts the string input to int 64 bit
+/*!
+     @param istr string input
+     @return The converted value or except in case of failure.
+*/ 
+vmp_int64 str_todigit64(vmp::str istr);
+
+//! Converts the string input to int in range min-max
+/*!
+     @param istr string input
+     @param min value accepted
+     @param max value accepted
+     @return The converted value or except in case of failure.
+*/ 
+vmp_int64 str_todigit64_range(vmp::str istr,vmp_int64 min,vmp_int64 max);
+
+
 //! Converts the string input to real
 /*!
      @param dstr string input
@@ -154,14 +171,14 @@ vmp::vector<vmp_byte> xstr_tobytes(vmp::str xstr);
 
 //! Converts a bytes vector to a string of hexadecimal values
 /*!
-     @param bstr byte vector input
+     @param bytes byte vector input
      @return The converted string value.
 */
 vmp::str bytes_toxstr(vmp::vector<vmp_byte> bytes);
 
 //! Converts a bytes vector to a string of hexadecimal values in human mode(the reverse function does not work)
 /*!
-     @param bstr byte vector input
+     @param bytes byte vector input
      @param delimiter byte delimiter
      @return The converted string value in human mode.
 */
